package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.KunpengDesktopCloudStorage;

/**
 * 鲲鹏桌面云云硬盘存储Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface KunpengDesktopCloudStorageMapper 
{
    /**
     * 查询鲲鹏桌面云云硬盘存储
     * 
     * @param id 鲲鹏桌面云云硬盘存储主键
     * @return 鲲鹏桌面云云硬盘存储
     */
    public KunpengDesktopCloudStorage selectKunpengDesktopCloudStorageById(Integer id);

    /**
     * 查询鲲鹏桌面云云硬盘存储列表
     * 
     * @param kunpengDesktopCloudStorage 鲲鹏桌面云云硬盘存储
     * @return 鲲鹏桌面云云硬盘存储集合
     */
    public List<KunpengDesktopCloudStorage> selectKunpengDesktopCloudStorageList(KunpengDesktopCloudStorage kunpengDesktopCloudStorage);

    /**
     * 新增鲲鹏桌面云云硬盘存储
     * 
     * @param kunpengDesktopCloudStorage 鲲鹏桌面云云硬盘存储
     * @return 结果
     */
    public int insertKunpengDesktopCloudStorage(KunpengDesktopCloudStorage kunpengDesktopCloudStorage);

    /**
     * 修改鲲鹏桌面云云硬盘存储
     * 
     * @param kunpengDesktopCloudStorage 鲲鹏桌面云云硬盘存储
     * @return 结果
     */
    public int updateKunpengDesktopCloudStorage(KunpengDesktopCloudStorage kunpengDesktopCloudStorage);

    /**
     * 删除鲲鹏桌面云云硬盘存储
     * 
     * @param id 鲲鹏桌面云云硬盘存储主键
     * @return 结果
     */
    public int deleteKunpengDesktopCloudStorageById(Integer id);

    /**
     * 批量删除鲲鹏桌面云云硬盘存储
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKunpengDesktopCloudStorageByIds(Integer[] ids);
}
